@@ -22,10 +22,8 @@
 namespace OCA\DAV\Connector\Sabre;
 
 use \Sabre\DAV\PropFind;
-use \Sabre\DAV\PropPatch;
 use OCP\IUserSession;
 use OCP\Share\IShare;
-use OCA\DAV\Connector\Sabre\ShareTypeList;
 
 /**
  * Sabre Plugin to provide share-related properties
@@ -143,7 +141,7 @@ class SharesPlugin extends \Sabre\DAV\ServerPlugin {
 		$shares = $this->shareManager->getSharesInFolder(
 			$this->userId,
 			$node,
-			false
+			true
 		);
 
 		$shareTypesByFileId = [];
