@@ -7,14 +7,23 @@ OC.L10N.register(
     "Saved" : "Salvestatud",
     "There was a problem saving your changes. Click to resume editing." : "Sinu muudatuste salvestamisega tekkis viga. Kliki muutmise jätkamiseks.",
     "An error occurred!" : "Tekis tõrge!",
+    "Edit" : "Redigeeri",
+    "Mixed" : "Segatud",
+    "Preview" : "Eelvaade",
+    "New text file" : "Uus tekstifail",
     "New text file.txt" : "Uus tekstifail.txt",
+    "You can not open a folder" : "Sa ei saa avada kausta",
+    "This file is too big to be opened. Please download the file instead." : "See fail on avamiseks liiga suur. Palun lae allla.",
     "Cannot read the file." : "Faili lugemine ebaõnnestus.",
     "Invalid file path supplied." : "Faili asukoht on vigane.",
     "The file is locked." : "Fail on lukus.",
     "An internal server error occurred." : "Tekkis sisemine serveri tõrge.",
+    "You can not write to a folder" : "Sa ei saa kirjutada kausta",
     "Cannot save file as it has been modified since opening" : "Faili ei saa salvestada, kune seda on pärast avamist muudetud",
     "Insufficient permissions" : "Pole piisavalt õiguseid",
     "File path not supplied" : "Faili asukoht on määramata",
-    "File mtime not supplied" : "Faili mtime puudub"
+    "File mtime not supplied" : "Faili mtime puudub",
+    "Text editor" : "Teksti redigeerija",
+    "Text file" : "Tekstifail"
 },
 "nplurals=2; plural=(n != 1);");
