@@ -14,12 +14,17 @@ OC.L10N.register(
     "No crop data provided" : "クロップデータは提供されません",
     "No valid crop data provided" : "有効なクロップデータは提供されません",
     "Crop is not square" : "クロップが正方形ではありません",
+    "Password reset is disabled" : "パスワードリセットは無効化されています",
     "Couldn't reset password because the token is invalid" : "トークンが無効なため、パスワードをリセットできませんでした",
     "Couldn't reset password because the token is expired" : "トークンが期限切れのため、パスワードをリセットできませんでした",
-    "Couldn't send reset email. Please make sure your username is correct." : "リセットメールを送信できませんでした。ユーザー名が正しいことを確認してください。",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "このユーザー名に紐付けられたメールアドレスがないため、リセットメールを送信できませんでした。管理者に問い合わせてください。",
+    "Password reset" : "パスワードのリセット",
+    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "次のボタンをクリックしてパスワードをリセットしてください。 パスワードリセットをリクエストしていない場合は、このメールを無視してください。",
+    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "パスワードをリセットするには、次のリンクをクリックしてください。 パスワードリセットをリクエストしていない場合は、このメールを無視してください。",
+    "Reset your password" : "パスワードをリセット",
     "%s password reset" : "%s パスワードリセット",
     "Couldn't send reset email. Please contact your administrator." : "リセットメールを送信できませんでした。管理者に問い合わせてください。",
+    "Couldn't send reset email. Please make sure your username is correct." : "リセットメールを送信できませんでした。ユーザー名が正しいことを確認してください。",
     "Preparing update" : "アップデートの準備中",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "修復警告:",
@@ -45,10 +50,12 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (非互換)",
     "Following apps have been disabled: %s" : "以下のアプリが無効にされています: %s",
     "Already up to date" : "すべて更新済",
+    "No contacts found" : "連絡先が見つかりません",
+    "Show all contacts …" : "全ての連絡先を表示...",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">コード整合性の確認で問題が発生しました。詳しくはこちら…</a>",
     "Settings" : "設定",
     "Connection to server lost" : "サーバとの接続が切断されました",
-    "Problem loading page, reloading in 5 seconds" : "ページ読込に問題がありました。5秒後に再読込します",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["ページ読込に問題がありました。%n秒後に再読込します"],
     "Saving..." : "保存中...",
     "Dismiss" : "閉じる",
     "This action requires you to confirm your password" : "この操作では、パスワードを確認する必要があります",
@@ -60,7 +67,7 @@ OC.L10N.register(
     "seconds ago" : "数秒前",
     "Logging in …" : "ログイン中...",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "パスワードをリセットするリンクをクリックしたので、メールを送信しました。しばらくたってもメールが届かなかった場合は、スパム/ジャンクフォルダーを確認してください。<br>それでも見つからなかった場合は、管理者に問合わせてください。",
-    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "ファイルが暗号化されています。リカバリーキーが有効でない場合は、パスワードをリセットした後にあなたのデータを元に戻す方法はありません。<br />どういうことか分からない場合は、操作を継続する前に管理者に問い合わせてください。<br />続けてよろしいでしょうか?",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "ファイルが暗号化されています。パスワードをリセットした場合、データを元に戻す方法はありません。<br />どういうことか分からない場合は、操作を継続する前に管理者に問い合わせてください。<br />続けてよろしいでしょうか?",
     "I know what I'm doing" : "どういう操作をしているか理解しています",
     "Password can not be changed. Please contact your administrator." : "パスワードは変更できません。管理者に問い合わせてください。",
     "No" : "いいえ",
@@ -68,7 +75,7 @@ OC.L10N.register(
     "No files in here" : "ここにはファイルがありません",
     "Choose" : "選択",
     "Error loading file picker template: {error}" : "ファイル選択テンプレートの読み込みエラー: {error}",
-    "Ok" : "OK",
+    "OK" : "OK",
     "Error loading message template: {error}" : "メッセージテンプレートの読み込みエラー: {error}",
     "read-only" : "読み取り専用",
     "_{count} file conflict_::_{count} file conflicts_" : ["{count} ファイルが競合"],
@@ -96,16 +103,14 @@ OC.L10N.register(
     "The reverse proxy headers configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If you are not accessing Nextcloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to Nextcloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "リバースプロキシヘッダーの設定が正しくないか、信頼できるプロキシからNextcloudにアクセスしています。信頼できるプロキシからNextcloudにアクセスしていない場合、これはセキュリティ上の問題であり、攻撃者が自分のIPアドレスを偽装してNextcloudに見えるようにしている可能性があります。詳細については、<a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">ドキュメント</a>をご覧ください。",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached は分散キャッシュとして設定されています。しかし、PHPモジュール \"memcache\"が間違ってインストールされています。  \\OC\\Memcache\\Memcached は、\"memcached\" のみをサポートしています。\"memcache\" ではありません。<a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki で両方のモジュールの情報</a> について確認してください。",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "いくつかのファイルでチェックサムが適合しませんでした。この問題を解決するためは、<a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">ドキュメント</a>の詳細を見てください。(<a href=\"{codeIntegrityDownloadEndpoint}\">不適合ファイルのリスト…</a> / <a href=\"{rescanEndpoint}\">再チェック…</a>)",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. We strongly recommend enabling this function." : "PHP 関数 \"set_time_limit\" は使用できません。これにより実行スクリプトが途中で停止されて、インストールを破壊する可能性があります。この機能を有効にすることを強くお勧めします。",
     "Error occurred while checking server setup" : "サーバー設定のチェック中にエラーが発生しました",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "データディレクトリとファイルがインターネットからアクセス可能になっている可能性があります。.htaccessファイルが機能していません。データディレクトリがアクセスされないようにWebサーバーを設定するか、Webサーバーのドキュメントルートからデータディレクトリを移動するように強くお勧めします。",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : ".htaccess ファイルが機能していないため、インターネットからあなたのデータディレクトリとファイルにアクセスできる可能性があります。Webサーバの設定を変更してデータディレクトリにアクセス出来ないようにするか、データディレクトリをドキュメントルートの外側に移動することを強く推奨します。",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP ヘッダは \"{expected}\" に設定されていません。これは潜在的なセキュリティリスクもしくはプライバシーリスクとなる可能性があるため、この設定を見直すことをおすすめします。",
     "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "HTTP ヘッダ の \"Strict-Transport-Security\" が少なくとも \"{seconds}\" 秒に設定されていません。 セキュリティを強化するため、<a href=\"{docUrl}\" rel=\"noreferrer\">セキュリティTips</a>を参照して、HSTS を有効にすることをおすすめします。",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "HTTP経由でアクセスしています。<a href=\"{docUrl}\">security tips</a>を参照して、代わりにHTTPSを使用するようサーバーを設定することを強くおすすめします。 instead as described in our .",
     "Shared" : "共有中",
     "Shared with {recipients}" : "{recipients} と共有",
-    "Error" : "エラー",
-    "Error while sharing" : "共有でエラー発生",
-    "Error while unsharing" : "共有解除でエラー発生",
     "Error setting expiration date" : "有効期限の設定でエラー発生",
     "The public link will expire no later than {days} days after it is created" : "URLによる共有は、作成してから {days} 日以内に有効期限切れになります",
     "Set expiration date" : "有効期限を設定",
@@ -118,44 +123,46 @@ OC.L10N.register(
     "Press ⌘-C to copy." : "⌘+Cを押してコピーします。",
     "Press Ctrl-C to copy." : "Ctrl+Cを押してコピーします。",
     "Resharing is not allowed" : "再共有は許可されていません",
+    "Share to {name}" : "{name} に共有する",
     "Share link" : "URLで共有",
     "Link" : "リンク",
     "Password protect" : "パスワード保護を有効化",
-    "Allow upload and editing" : "アップロードと編集を許可する",
-    "File drop (upload only)" : "ファイルドロップ(アップロードのみ)",
+    "Allow editing" : "編集を許可",
     "Email link to person" : "メールリンク",
     "Send" : "送信",
+    "Allow upload and editing" : "アップロードと編集を許可する",
+    "Read only" : "読み取り専用",
+    "File drop (upload only)" : "ファイルドロップ(アップロードのみ)",
     "Shared with you and the group {group} by {owner}" : "あなたと {owner} のグループ {group} で共有中",
     "Shared with you by {owner}" : "{owner} より共有中",
+    "Choose a password for the mail share" : "メール共有のパスワードを選択",
     "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} がリンク経由で共有",
     "group" : "グループ",
     "remote" : "リモート",
     "email" : "メール",
+    "shared by {sharer}" : "共有した人 {sharer}",
     "Unshare" : "共有解除",
-    "can reshare" : "再共有可能",
-    "can edit" : "編集を許可",
-    "can create" : "作成できます",
-    "can change" : "変更できます",
-    "can delete" : "削除できます",
-    "access control" : "アクセス権限",
+    "Can reshare" : "再共有可能",
+    "Can edit" : "編集可能",
+    "Can create" : "作成可能",
+    "Can change" : "変更可能",
+    "Can delete" : "削除可能",
+    "Access control" : "アクセス制御",
     "Could not unshare" : "共有の解除ができませんでした",
+    "Error while sharing" : "共有でエラー発生",
     "Share details could not be loaded for this item." : "共有の詳細はこのアイテムによりロードできませんでした。",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["オートコンプリートには{count}文字以上必要です"],
+    "This list is maybe truncated - please refine your search term to see more results." : "このリストは切り捨てられている可能性があります - 検索語句を絞り込んで検索結果を表示してください。",
     "No users or groups found for {search}" : "{search} の検索でユーザー、グループが見つかりません",
     "No users found for {search}" : "{search} のユーザーはいませんでした",
     "An error occurred. Please try again" : "エラーが発生しました。もう一度実行してください。",
     "{sharee} (group)" : "{sharee} (グループ)",
     "{sharee} (remote)" : "{sharee} (リモート)",
     "{sharee} (email)" : "{sharee} (メール)",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
     "Share" : "共有",
-    "Share with people on other servers using their Federated Cloud ID username@example.com/nextcloud" : "Federated Cloud ID（ username@example.com/nextcloud ）を使用して他のサーバーのユーザーと共有する",
-    "Share with users or by mail..." : "ユーザーまたはメールで共有する...",
-    "Share with users or remote users..." : "ユーザーまたはリモートユーザーと共有する...",
-    "Share with users, remote users or by mail..." : "ユーザー、リモートユーザーまたはメールで共有する...",
-    "Share with users or groups..." : "ユーザーやグループと共有する...",
-    "Share with users, groups or by mail..." : "ユーザー、グループ、またはメールで共有...",
-    "Share with users, groups or remote users..." : "ユーザー、グループ、またはリモートユーザーと共有する...",
-    "Share with users, groups, remote users or by mail..." : "ユーザー、グループ、リモートユーザーまたはメールで共有...",
-    "Share with users..." : "ユーザーと共有する...",
+    "Name or email address..." : "名前またはメールアドレス",
+    "Error" : "エラー",
     "Error removing share" : "共有の削除エラー",
     "Non-existing tag #{tag}" : "存在しないタグ#{tag}",
     "restricted" : "制限済",
@@ -165,17 +172,12 @@ OC.L10N.register(
     "Rename" : "名前の変更",
     "Collaborative tags" : "コラボタグ",
     "No tags found" : "タグが見つかりません",
-    "The object type is not specified." : "オブジェクトタイプが指定されていません。",
-    "Enter new" : "新規に入力",
-    "Add" : "追加",
-    "Edit tags" : "タグを編集",
-    "Error loading dialog template: {error}" : "メッセージテンプレートの読み込みエラー: {error}",
-    "No tags selected for deletion." : "削除するタグが選択されていません。",
     "unknown text" : "不明なテキスト",
     "Hello world!" : "Hello world!",
     "sunny" : "快晴",
     "Hello {name}, the weather is {weather}" : "こんにちは､ {name}､ 天気は{weather}です",
     "Hello {name}" : " {name}さん､こんにちは",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>これが検索結果です<script>alert(1)</script></strong>",
     "new" : "新規",
     "_download %n file_::_download %n files_" : ["%n個のファイルをダウンロード"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "更新が進行中です。このページを離れると一部の環境では処理が中断されてしまう可能性があります。",
@@ -185,9 +187,9 @@ OC.L10N.register(
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "アップデートできませんでした。この問題に対する詳細な情報については、<a href=\"{url}\">フォーラムの投稿を確認してください</a> ",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "アップデートできませんでした。<a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud コミュニティ</a> に問題を報告してください。",
     "Continue to Nextcloud" : "Nextcloud に進む",
-    "The update was successful. Redirecting you to Nextcloud now." : "アップデート成功。Nextcloud にリダイレクトします。",
+    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["更新が成功しました。 %n 秒後に Nextcloud にリダイレクトします。"],
     "Searching other places" : "他の場所の検索",
-    "No search results in other folders for '{tag}{filter}{endtag}'" : "他のフォルダに '{tag}{filter}{endtag}' の検索結果はありません",
+    "No search results in other folders for {tag}{filter}{endtag}" : "他のフォルダーに {tag}{filter}{endtag} の検索結果はありません",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["他のフォルダーの検索件数 {count}"],
     "Personal" : "個人",
     "Users" : "ユーザー",
@@ -198,9 +200,6 @@ OC.L10N.register(
     "File not found" : "ファイルが見つかりません",
     "The specified document has not been found on the server." : "サーバーに指定されたファイルが見つかりませんでした。",
     "You can click here to return to %s." : "ここをクリックすると、 %s に戻れます。",
-    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "こんにちは、\n\n%s があなたと %s を共有したことをお知らせします。\nそれを表示: %s\n",
-    "The share will expire on %s." : "共有は %s で有効期限が切れます。",
-    "Cheers!" : "それでは！",
     "Internal Server Error" : "内部サーバーエラー",
     "The server encountered an internal error and was unable to complete your request." : "サーバー内でエラーが発生したため、リクエストを完了できませんでした。",
     "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "このエラーが繰り返し表示されるようであれば、以下の技術情報を添付してサーバー管理者に問い合わせてください。",
@@ -230,6 +229,7 @@ OC.L10N.register(
     "Database name" : "データベース名",
     "Database tablespace" : "データベースの表領域",
     "Database host" : "データベースのホスト名",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "ポート番号をホスト名とともに指定してください(例：localhost：5432)。",
     "Performance warning" : "パフォーマンス警告",
     "SQLite will be used as database." : "SQLiteをデータベースとして使用しています。",
     "For larger installations we recommend to choose a different database backend." : "大規模な運用では別のデータベースを選択することをお勧めします。",
@@ -239,7 +239,7 @@ OC.L10N.register(
     "Need help?" : "ヘルプが必要ですか？",
     "See the documentation" : "ドキュメントを確認してください",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "このアプリケーションの動作にはJavaScriptが必要です。\n {linkstart}JavaScriptを有効にし{linkend} 、ページを更新してください。 ",
-    "Log out" : "ログアウト",
+    "More apps" : "さらにアプリ",
     "Search" : "検索",
     "This action requires you to confirm your password:" : "この操作では、パスワードを確認する必要があります:",
     "Confirm your password" : "パスワードを確認",
@@ -253,20 +253,15 @@ OC.L10N.register(
     "Log in" : "ログイン",
     "Stay logged in" : "ログインしたままにする",
     "Alternative Logins" : "代替ログイン",
-    "Use the following link to reset your password: {link}" : "パスワードをリセットするには次のリンクをクリックしてください: {link}",
+    "App token" : "アプリのトークン",
     "New password" : "新しいパスワードを入力",
     "New Password" : "新しいパスワード",
     "Reset password" : "パスワードをリセット",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "こんにちは、<br><br>%sがあなたと »%s« を共有したことをお知らせします。<br><a href=\"%s\">それを表示</a><br><br>",
-    "This Nextcloud instance is currently in single user mode." : "このNextcloudインスタンスは、現在シングルユーザーモードです。",
-    "This means only administrators can use the instance." : "これは、管理者のみがインスタンスを利用できることを意味しています。",
-    "Contact your system administrator if this message persists or appeared unexpectedly." : "このメッセージが引き続きもしくは予期せず現れる場合は、システム管理者に問い合わせてください。",
-    "Thank you for your patience." : "しばらくお待ちください。",
     "Two-factor authentication" : "2要素認証",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "アカウントのセキュリティが強化されています。第2因子を使用して認証してください。",
+    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "このアカウントは強化セキュリティが適用されています。第二経路から認証してください。",
     "Cancel log in" : "ログインをキャンセルする",
     "Use backup code" : "バックアップコードを使用する",
-    "Error while validating your second factor" : "第2因子を検証中にエラーが発生しました",
+    "Error while validating your second factor" : "第二要素の検証でエラーが発生しました",
     "You are accessing the server from an untrusted domain." : "信頼されていないドメインからサーバーにアクセスしています。",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "管理者に問い合わせてください。このサーバーの管理者の場合は、\"trusted_domain\" の設定を config/config.php に設定してください。config/config.sample.php にサンプルの設定方法が記載してあります。",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "環境により、下のボタンで信頼するドメインに追加する必要があるかもしれません。",
@@ -281,104 +276,46 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "大規模なサイトの場合、ブラウザーがタイムアウトする可能性があるため、インストールディレクトリで以下のコマンドを実行することもできます。",
     "Detailed logs" : "詳細ログ",
     "Update needed" : "更新が必要です",
-    "Please use the command line updater because you have a big instance." : "データ量が大きいため、コマンドラインでの更新を利用してください。",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "不明な場合、<a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">ドキュメント</a>を参照してください。",
     "This %s instance is currently in maintenance mode, which may take a while." : "このサーバー %s は現在メンテナンスモードです。しばらくお待ちください。",
     "This page will refresh itself when the %s instance is available again." : "この画面は、サーバー %s の再起動後に自動的に更新されます。",
-    "Error loading tags" : "タグの読み込みエラー",
-    "Tag already exists" : "タグはすでに存在します",
-    "Error deleting tag(s)" : "タグの削除エラー",
-    "Error tagging" : "タグの付与エラー",
-    "Error untagging" : "タグの解除エラー",
-    "Error favoriting" : "お気に入りに追加エラー",
-    "Error unfavoriting" : "お気に入りから削除エラー",
-    "Couldn't send mail to following users: %s " : "次のユーザーにメールを送信できませんでした: %s",
-    "Sunday" : "日",
-    "Monday" : "月",
-    "Tuesday" : "火",
-    "Wednesday" : "水",
-    "Thursday" : "木",
-    "Friday" : "金",
-    "Saturday" : "土",
-    "Sun." : "日",
-    "Mon." : "月",
-    "Tue." : "火",
-    "Wed." : "水",
-    "Thu." : "木",
-    "Fri." : "金",
-    "Sat." : "土",
-    "Su" : "日",
-    "Mo" : "月",
-    "Tu" : "火",
-    "We" : "水",
-    "Th" : "木",
-    "Fr" : "金",
-    "Sa" : "土",
-    "January" : "1月",
-    "February" : "2月",
-    "March" : "3月",
-    "April" : "4月",
-    "May" : "5月",
-    "June" : "6月",
-    "July" : "7月",
-    "August" : "8月",
-    "September" : "9月",
-    "October" : "10月",
-    "November" : "11月",
-    "December" : "12月",
-    "Jan." : "1月",
-    "Feb." : "2月",
-    "Mar." : "3月",
-    "Apr." : "4月",
-    "May." : "5月",
-    "Jun." : "6月",
-    "Jul." : "7月",
-    "Aug." : "8月",
-    "Sep." : "9月",
-    "Oct." : "10月",
-    "Nov." : "11月",
-    "Dec." : "12月",
-    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "このサーバーはインターネットに接続していません。この場合、外部ストレージのマウント、更新の通知やサードパーティ製のアプリ、といった一部の機能が利用できません。また、リモート接続でのファイルアクセス、通知メールの送信のような機能も利用できないことがあります。すべての機能を利用するには、このサーバーのインターネット接続を有効にすることをお勧めします。",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "リバースプロキシのヘッダー設定が間違っているか、または信頼されたプロキシからownCloudにアクセスしていません。もし、信頼されたプロキシからアクセスされているのでないなら、攻撃者の詐称されたIPアドレスから ownCloudを見ることができるように許可されていて、セキュリティに問題があります。詳細な情報は、 <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">ドキュメント</a>を確認してください。",
-    "Allow editing" : "編集を許可",
-    "Hide file listing" : "ファイルリストを隠す",
-    "Sending ..." : "送信中...",
-    "Email sent" : "メールを送信しました",
-    "Send link via email" : "メールでリンクを送信",
-    "notify by email" : "メールで通知",
-    "can share" : "共有可",
-    "create" : "作成",
-    "change" : "更新",
-    "delete" : "削除",
-    "{sharee} (at {server})" : "{sharee} ({server} で)",
-    "Share with users…" : "ユーザーと共有...",
-    "Share with users, groups or remote users…" : "ユーザー、グループもしくはリモートユーザーと共有 ...",
-    "Share with users or groups…" : "ユーザーもしくはグループと共有...",
-    "Share with users or remote users…" : "ユーザーもしくはリモートユーザーと共有 ...",
-    "Warning" : "警告",
-    "Error while sending notification" : "通知送信中にエラーが発生",
-    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "アップグレード実行中です。このページを離れると、一部の環境では処理が中断されてしまうことがあります。",
-    "Updating to {version}" : "{version}に更新中",
-    "The update was successful. There were warnings." : "更新は成功しました。警告があります。",
-    "No search results in other folders" : "他のフォルダーの検索結果はありません",
-    "Two-step verification" : "2段階認証",
-    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "あなたのアカウントではセキュリティ拡張が有効になっています。2要素認証を使って認証してください。",
-    "Cancel login" : "ログインをキャンセル",
-    "Please authenticate using the selected factor." : "選択したデバイスを利用して認証してください。",
-    "An error occured while verifying the token" : "トークンの整合性チェックでエラーが発生",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Webサーバーは適切にホスト名 \"{url}\" が引けるように設定されていません。詳細については、<a target=\"_blank\" href=\"{docLink}\">ドキュメント</a>を参照してください。",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "メモリキャッシュが設定されていません。パフォーマンスを向上させるには、使用可能な場合はmemcacheを設定してください。詳細については、<a target=\"_blank\" href=\"{docLink}\">ドキュメント</a>を参照してください。",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandomがPHPから読み込みできません。これはセキュリティの理由から非常に推奨されていません。詳細については、<a target=\"_blank\" href=\"{docLink}\">ドキュメント</a>を参照してください。",
-    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "あなたは現在PHP {version}を実行しています。ディストリビューションでサポートされたら、すぐにPHPのバージョンをアップグレードして<a target=\"_blank\" href=\"{phpLink}\"> PHPグループが提供するパフォーマンスとセキュリティのアップデート</a>を利用することをお勧めします。",
-    "The reverse proxy headers configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If you are not accessing Nextcloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to Nextcloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "リバースプロキシヘッダーの設定が正しくないか、信頼できるプロキシからNextcloudにアクセスしています。信頼できるプロキシからNextcloudにアクセスしていない場合、これはセキュリティ上の問題があり、攻撃者が自分のIPアドレスを偽装してNextcloudに見えるようにしている可能性があります。詳細については、<a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">ドキュメント</a>をご覧ください。",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached は分散キャッシュとして設定されています。しかし、PHPモジュール \"memcache\"が間違ってインストールされています。  \\OC\\Memcache\\Memcached は、\"memcached\" のみをサポートしています。\"memcache\" ではありません。<a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki で両方のモジュールの情報</a> について確認してください。",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "一部のファイルが整合性チェックに合格していません。この問題の解決方法の詳細については、<a target=\"_blank\" href=\"{docLink}\">ドキュメント</a>をご覧ください。 (<a href=\"{codeIntegrityDownloadEndpoint}\">無効なファイルのリスト... </a> / <a href=\"{rescanEndpoint}\">再スキャン... </a>)",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "HTTP ヘッダ の \"Strict-Transport-Security\" が少なくとも \"{seconds}\" 秒に設定されていません。 セキュリティを強化するため、<a href=\"{docUrl}\" rel=\"noreferrer\">セキュリティTips</a>を参照して、HSTS を有効にすることをおすすめします。",
-    "An error occured. Please try again" : "エラーが発生しました。再度試行してください。",
-    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "次の形式で指定して他のownCloudのユーザーと、共有",
-    "not assignable" : "割り当て不可",
-    "Updating {productName} to version {version}, this may take a while." : "{productName} をバージョン{version} に更新するには、しばらく時間がかかることがあります。",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "サーバーを正しく設定する方法については、<a href=\"%s\" target=\"_blank\">ドキュメント</a>をご覧ください。",
-    "An internal error occured." : "内部エラーが発生しました"
+    "Contact your system administrator if this message persists or appeared unexpectedly." : "このメッセージが引き続きもしくは予期せず現れる場合は、システム管理者に問い合わせてください。",
+    "Thank you for your patience." : "しばらくお待ちください。",
+    "Problem loading page, reloading in 5 seconds" : "ページ読込に問題がありました。5秒後に再読込します",
+    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "ファイルが暗号化されています。リカバリーキーが有効でない場合は、パスワードをリセットした後にあなたのデータを元に戻す方法はありません。<br />どういうことか分からない場合は、操作を継続する前に管理者に問い合わせてください。<br />続けてよろしいでしょうか?",
+    "Ok" : "OK",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "データディレクトリとファイルがインターネットからアクセス可能になっている可能性があります。.htaccessファイルが機能していません。データディレクトリがアクセスされないようにWebサーバーを設定するか、Webサーバーのドキュメントルートからデータディレクトリを移動するように強くお勧めします。",
+    "Error while unsharing" : "共有解除でエラー発生",
+    "can reshare" : "再共有可能",
+    "can edit" : "編集を許可",
+    "can create" : "作成できます",
+    "can change" : "変更できます",
+    "can delete" : "削除できます",
+    "access control" : "アクセス権限",
+    "Share with people on other servers using their Federated Cloud ID username@example.com/nextcloud" : "Federated Cloud ID（ username@example.com/nextcloud ）を使用して他のサーバーのユーザーと共有する",
+    "Share with users or by mail..." : "ユーザーまたはメールで共有する...",
+    "Share with users or remote users..." : "ユーザーまたはリモートユーザーと共有する...",
+    "Share with users, remote users or by mail..." : "ユーザー、リモートユーザーまたはメールで共有する...",
+    "Share with users or groups..." : "ユーザーやグループと共有する...",
+    "Share with users, groups or by mail..." : "ユーザー、グループ、またはメールで共有...",
+    "Share with users, groups or remote users..." : "ユーザー、グループ、またはリモートユーザーと共有する...",
+    "Share with users, groups, remote users or by mail..." : "ユーザー、グループ、リモートユーザーまたはメールで共有...",
+    "Share with users..." : "ユーザーと共有する...",
+    "The object type is not specified." : "オブジェクトタイプが指定されていません。",
+    "Enter new" : "新規に入力",
+    "Add" : "追加",
+    "Edit tags" : "タグを編集",
+    "Error loading dialog template: {error}" : "メッセージテンプレートの読み込みエラー: {error}",
+    "No tags selected for deletion." : "削除するタグが選択されていません。",
+    "The update was successful. Redirecting you to Nextcloud now." : "アップデート成功。Nextcloud にリダイレクトします。",
+    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "こんにちは、\n\n%s があなたと %s を共有したことをお知らせします。\nそれを表示: %s\n",
+    "The share will expire on %s." : "共有は %s で有効期限が切れます。",
+    "Cheers!" : "それでは！",
+    "Log out" : "ログアウト",
+    "Use the following link to reset your password: {link}" : "パスワードをリセットするには次のリンクをクリックしてください: {link}",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "こんにちは、<br><br>%sがあなたと »%s« を共有したことをお知らせします。<br><a href=\"%s\">それを表示</a><br><br>",
+    "This Nextcloud instance is currently in single user mode." : "このNextcloudインスタンスは、現在シングルユーザーモードです。",
+    "This means only administrators can use the instance." : "これは、管理者のみがインスタンスを利用できることを意味しています。",
+    "Please use the command line updater because you have a big instance." : "データ量が大きいため、コマンドラインでの更新を利用してください。"
 },
 "nplurals=1; plural=0;");
