@@ -34,7 +34,6 @@ namespace OC;
 use InterfaSys\LogNormalizer\Normalizer;
 
 use \OCP\ILogger;
-use OCP\Security\StringUtils;
 use OCP\Util;
 
 /**
@@ -63,6 +62,7 @@ class Log implements ILogger {
 
 	protected $methodsWithSensitiveParameters = [
 		// Session/User
+		'completeLogin',
 		'login',
 		'checkPassword',
 		'loginWithPassword',
@@ -88,7 +88,8 @@ class Log implements ILogger {
 		'decrypt',
 
 		//LoginController
-		'tryLogin'
+		'tryLogin',
+		'confirmPassword',
 	];
 
 	/**
@@ -106,7 +107,8 @@ class Log implements ILogger {
 
 		// FIXME: Add this for backwards compatibility, should be fixed at some point probably
 		if($logger === null) {
-			$this->logger = 'OC\\Log\\'.ucfirst($this->config->getValue('log_type', 'owncloud'));
+			$logType = $this->config->getValue('log_type', 'file');
+			$this->logger = static::getLogClass($logType);
 			call_user_func(array($this->logger, 'init'));
 		} else {
 			$this->logger = $logger;
@@ -303,13 +305,18 @@ class Log implements ILogger {
 	/**
 	 * Logs an exception very detailed
 	 *
-	 * @param \Exception | \Throwable $exception
+	 * @param \Exception|\Throwable $exception
 	 * @param array $context
 	 * @return void
 	 * @since 8.2.0
 	 */
 	public function logException($exception, array $context = array()) {
-		$exception = array(
+		$level = Util::ERROR;
+		if (isset($context['level'])) {
+			$level = $context['level'];
+			unset($context['level']);
+		}
+		$data = array(
 			'Exception' => get_class($exception),
 			'Message' => $exception->getMessage(),
 			'Code' => $exception->getCode(),
@@ -317,9 +324,31 @@ class Log implements ILogger {
 			'File' => $exception->getFile(),
 			'Line' => $exception->getLine(),
 		);
-		$exception['Trace'] = preg_replace('!(' . implode('|', $this->methodsWithSensitiveParameters) . ')\(.*\)!', '$1(*** sensitive parameters replaced ***)', $exception['Trace']);
+		$data['Trace'] = preg_replace('!(' . implode('|', $this->methodsWithSensitiveParameters) . ')\(.*\)!', '$1(*** sensitive parameters replaced ***)', $data['Trace']);
 		$msg = isset($context['message']) ? $context['message'] : 'Exception';
-		$msg .= ': ' . json_encode($exception);
-		$this->error($msg, $context);
+		$msg .= ': ' . json_encode($data);
+		$this->log($level, $msg, $context);
+	}
+
+	/**
+	 * @param string $logType
+	 * @return string
+	 * @internal
+	 */
+	public static function getLogClass($logType) {
+		switch (strtolower($logType)) {
+			case 'errorlog':
+				return \OC\Log\Errorlog::class;
+			case 'syslog':
+				return \OC\Log\Syslog::class;
+			case 'file':
+				return \OC\Log\File::class;
+
+			// Backwards compatibility for old and fallback for unknown log types
+			case 'owncloud':
+			case 'nextcloud':
+			default:
+				return \OC\Log\File::class;
+		}
 	}
 }
